==> haskell-murmur-hash-0.1.0.10-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-murmur-hash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 murmur-hash
version:              0.1.0.10
visibility:           public
id:                   murmur-hash-0.1.0.10-JJ8DIkJifit7ZKugmvJNM7
key:                  murmur-hash-0.1.0.10-JJ8DIkJifit7ZKugmvJNM7
license:              BSD-3-Clause
maintainer:           Thomas Schilling <nominolo@googlemail.com>
author:               Thomas Schilling
stability:            provisional
homepage:             http://github.com/nominolo/murmur-hash
synopsis:             MurmurHash2 implementation for Haskell.
description:
    Implements MurmurHash2, a good, fast, general-purpose,
    non-cryptographic hashing function.  See
    <http://murmurhash.googlepages.com/> for details.

    This implementation is pure Haskell, so it might be a bit slower
    than a C FFI binding.

category:             Data, Digest
abi:                  48f8789d49579f29fdca8f96ccf31b39
exposed:              True
exposed-modules:      Data.Digest.Murmur32 Data.Digest.Murmur64
import-dirs:          /usr/lib/ghc-9.0.1/site-local/murmur-hash-0.1.0.10
library-dirs:         /usr/lib/ghc-9.0.1/site-local/murmur-hash-0.1.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/murmur-hash-0.1.0.10
hs-libraries:         HSmurmur-hash-0.1.0.10-JJ8DIkJifit7ZKugmvJNM7
depends:              base-4.15.0.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-murmur-hash/html/murmur-hash.haddock
haddock-html:         /usr/share/doc/haskell-murmur-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-murmur-hash-0.1.0.10-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-murmur-hash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 murmur-hash
version:              0.1.0.10
visibility:           public
id:                   murmur-hash-0.1.0.10-AJwBzcDKjnOE7vktXnd5qt
key:                  murmur-hash-0.1.0.10-AJwBzcDKjnOE7vktXnd5qt
license:              BSD-3-Clause
maintainer:           Thomas Schilling <nominolo@googlemail.com>
author:               Thomas Schilling
stability:            provisional
homepage:             http://github.com/nominolo/murmur-hash
synopsis:             MurmurHash2 implementation for Haskell.
description:
    Implements MurmurHash2, a good, fast, general-purpose,
    non-cryptographic hashing function.  See
    <http://murmurhash.googlepages.com/> for details.

    This implementation is pure Haskell, so it might be a bit slower
    than a C FFI binding.

category:             Data, Digest
abi:                  c813eb3d7b72a08fdc06066687964f02
exposed:              True
exposed-modules:      Data.Digest.Murmur32 Data.Digest.Murmur64
import-dirs:          /usr/lib/ghc-9.0.2/site-local/murmur-hash-0.1.0.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/murmur-hash-0.1.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/murmur-hash-0.1.0.10
hs-libraries:         HSmurmur-hash-0.1.0.10-AJwBzcDKjnOE7vktXnd5qt
depends:              base-4.15.1.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-murmur-hash/html/murmur-hash.haddock
haddock-html:         /usr/share/doc/haskell-murmur-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
